@@ -1,6 +1,6 @@
 
 package Module::Spec::V2;
-$Module::Spec::V2::VERSION = '0.8.0';
+$Module::Spec::V2::VERSION = '0.9.0';
 # ABSTRACT: Load modules based on V2 specifications
 use 5.012;
 
@@ -78,7 +78,8 @@ sub need_module {
 
     my ( $m, @v ) = _parse_module_spec( $_[-1] )
       or croak(qq{Can't parse $_[-1]});
-    return _need_module( $opts, $m, @v );
+    return _need_module( $opts, $m, @v ) unless $opts->{try};
+    return _try_module( $opts, $m, @v );
 }
 
 # generate_code($spec, \%opts);
@@ -114,6 +115,11 @@ sub need_modules {
     goto &$sub;
 }
 
+sub try_modules {
+    unshift @_, '-any';
+    goto &need_modules;
+}
+
 sub _need_all_modules {
     map { scalar need_module($_) } @_;
 }
@@ -211,6 +217,13 @@ sub _need_first_module {
 #pod and which should return true if the module should be loaded
 #pod with C<require> or false otherwise.
 #pod
+#pod =item try
+#pod
+#pod     try => 0    # default
+#pod     try => 1
+#pod
+#pod If C<try> is true, it behaves as L</"try_module">.
+#pod
 #pod =back
 #pod
 #pod =head2 need_modules
@@ -300,6 +313,16 @@ sub _need_first_module {
 #pod
 #pod =back
 #pod
+#pod =head2 try_modules
+#pod
+#pod     @modules = try_modules(@spec);
+#pod     @modules = try_modules(\%spec);
+#pod
+#pod Shortcut for
+#pod
+#pod     @modules = need_modules(-any => @spec);
+#pod     @modules = need_modules(-any => \%spec);
+#pod
 #pod =head1 CAVEATS
 #pod
 #pod =over 4
@@ -332,7 +355,7 @@ Module::Spec::V2 - Load modules based on V2 specifications
 
 =head1 VERSION
 
-version 0.8.0
+version 0.9.0
 
 =head1 SYNOPSIS
 
@@ -411,6 +434,13 @@ passed the module name and version requirement (if any)
 and which should return true if the module should be loaded
 with C<require> or false otherwise.
 
+=item try
+
+    try => 0    # default
+    try => 1
+
+If C<try> is true, it behaves as L</"try_module">.
+
 =back
 
 =head2 need_modules
@@ -500,6 +530,16 @@ with C<require> or false otherwise.
 
 =back
 
+=head2 try_modules
+
+    @modules = try_modules(@spec);
+    @modules = try_modules(\%spec);
+
+Shortcut for
+
+    @modules = need_modules(-any => @spec);
+    @modules = need_modules(-any => \%spec);
+
 =head1 CAVEATS
 
 =over 4
